@@ -9,20 +9,20 @@ use utf8;
 use strictures 2;
 use version;
 use Role::Commons -all;
+use namespace::autoclean 0.16;
 use autodie;
 
 use Moo;
+use MooX::StrictConstructor;
 with 'MooX::Role::Logger', 'Boxer::Role::Interact';
 
-use namespace::clean;
-
 =head1 VERSION
 
-Version v1.1.7
+Version v1.3.0
 
 =cut
 
-our $VERSION = version->declare("v1.1.7");
+our $VERSION = version->declare("v1.3.0");
 
 =head1 AUTHOR
 
